==> haskell-tagsoup-0.14.8-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagsoup
version:              0.14.8
visibility:           public
id:                   tagsoup-0.14.8-3Z3pFAyYj0W2GMnmSKLsKC
key:                  tagsoup-0.14.8-3Z3pFAyYj0W2GMnmSKLsKC
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/tagsoup#readme
synopsis:
    Parsing and extracting information from (possibly malformed) HTML/XML documents

description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.

    Users should start from the "Text.HTML.TagSoup" module.

category:             XML
abi:                  1cc8b92a6e41bc8ddede5dfc12d1abd4
exposed:              True
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike

hidden-modules:
    Text.HTML.TagSoup.Generated Text.HTML.TagSoup.Implementation
    Text.HTML.TagSoup.Manual Text.HTML.TagSoup.Options
    Text.HTML.TagSoup.Parser Text.HTML.TagSoup.Render
    Text.HTML.TagSoup.Specification Text.HTML.TagSoup.Type

import-dirs:          /usr/lib/ghc-8.10.2/site-local/tagsoup-0.14.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tagsoup-0.14.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tagsoup-0.14.8
hs-libraries:         HStagsoup-0.14.8-3Z3pFAyYj0W2GMnmSKLsKC
depends:
    base-4.14.1.0 bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html:         /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagsoup-0.14.8-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagsoup
version:              0.14.8
visibility:           public
id:                   tagsoup-0.14.8-2zMWFucJd3SFh8rfBD4zdE
key:                  tagsoup-0.14.8-2zMWFucJd3SFh8rfBD4zdE
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/tagsoup#readme
synopsis:
    Parsing and extracting information from (possibly malformed) HTML/XML documents

description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.

    Users should start from the "Text.HTML.TagSoup" module.

category:             XML
abi:                  346431639f3dfaa7a701a2c3340e9cce
exposed:              True
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike

hidden-modules:
    Text.HTML.TagSoup.Generated Text.HTML.TagSoup.Implementation
    Text.HTML.TagSoup.Manual Text.HTML.TagSoup.Options
    Text.HTML.TagSoup.Parser Text.HTML.TagSoup.Render
    Text.HTML.TagSoup.Specification Text.HTML.TagSoup.Type

import-dirs:          /usr/lib/ghc-8.10.2/site-local/tagsoup-0.14.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tagsoup-0.14.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tagsoup-0.14.8
hs-libraries:         HStagsoup-0.14.8-2zMWFucJd3SFh8rfBD4zdE
depends:
    base-4.14.1.0 bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html:         /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
